@@ -1,4 +1,4 @@
-assignMutations<-function( dm, finalSPs,densities, max_PM=6){
+assignMutations<-function( dm, finalSPs,densities, max_PM=6, min_CellFreq=0.1){
 if(is.null(dim(finalSPs))){
 	precision=finalSPs["precision"];
 	spFreq=finalSPs["Mean Weighted"];
@@ -6,7 +6,7 @@ if(is.null(dim(finalSPs))){
 	spFreq=finalSPs[,"Mean Weighted"];
 	precision=finalSPs[1,"precision"];
 }
-freq=t(seq(0.1,1,by=precision/10));
+freq=t(seq(min_CellFreq,1,by=precision/10));
 ##Assign mutations to SPs
 idx=matrix(NA,1,size(finalSPs,1));
 for (i in 1:size(finalSPs,1)){
